@@ -17,7 +17,7 @@ using namespace Prison;
 
 class ReedSolomonTest : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 private Q_SLOTS:
     void rsTest_data()
     {
@@ -26,13 +26,17 @@ private Q_SLOTS:
         QTest::addColumn<BitVector>("input");
         QTest::addColumn<BitVector>("output");
 
-        BitVector in, out;
+        BitVector in;
+        BitVector out;
         out.appendMSB(0, 20);
         QTest::newRow("empty") << (int)ReedSolomon::GF16 << 5 << in << out;
 
-        in.clear(); out.clear();
+        in.clear();
+        out.clear();
         in.appendMSB(0x5c, 8);
-        out.appendMSB(7, 6); out.appendMSB(5, 7); out.appendMSB(0x4d, 7);
+        out.appendMSB(7, 6);
+        out.appendMSB(5, 7);
+        out.appendMSB(0x4d, 7);
         QTest::newRow("GF16") << (int)ReedSolomon::GF16 << 5 << in << out;
     }
 
